==> eric_4.3.7.1.orig.tar.gz: eric4-4.3.7.1/eric/QScintilla/Lexers/LexerLua.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2005 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing a Lua lexer with some additional methods.
"""

from PyQt4.Qsci import QsciLexerLua
from PyQt4.QtCore import QString, QStringList

from Lexer import Lexer
import Preferences

class LexerLua(QsciLexerLua, Lexer):
    """ 
    Subclass to implement some additional lexer dependant methods.
    """
    def __init__(self, parent=None):
        """
        Constructor
        
        @param parent parent widget of this lexer
        """
        QsciLexerLua.__init__(self, parent)
        Lexer.__init__(self)
        
        self.commentString = QString("--")
    
    def initProperties(self):
        """
        Public slot to initialize the properties.
        """
        self.setFoldCompact(Preferences.getEditor("AllFoldCompact"))
    
    def autoCompletionWordSeparators(self):
        """
        Public method to return the list of separators for autocompletion.
        
        @return list of separators (QStringList)
        """
        return QStringList() << ':' << '.'
    
    def isCommentStyle(self, style):
        """
        Public method to check, if a style is a comment style.
        
        @return flag indicating a comment style (boolean)
        """
        return style in [QsciLexerLua.Comment, 
                         QsciLexerLua.LineComment]
    
    def isStringStyle(self, style):
        """
        Public method to check, if a style is a string style.
        
        @return flag indicating a string style (boolean)
        """
        return style in [QsciLexerLua.String, 
                         QsciLexerLua.LiteralString, 
                         QsciLexerLua.UnclosedString]

==> eric4-4.5.13.tar.gz: eric4-4.5.13/eric/QScintilla/Lexers/LexerLua.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2005 - 2013 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module implementing a Lua lexer with some additional methods.
"""

from PyQt4.Qsci import QsciLexerLua
from PyQt4.QtCore import QString, QStringList

from Lexer import Lexer
import Preferences

class LexerLua(QsciLexerLua, Lexer):
    """ 
    Subclass to implement some additional lexer dependant methods.
    """
    def __init__(self, parent=None):
        """
        Constructor
        
        @param parent parent widget of this lexer
        """
        QsciLexerLua.__init__(self, parent)
        Lexer.__init__(self)
        
        self.commentString = QString("--")
    
    def initProperties(self):
        """
        Public slot to initialize the properties.
        """
        self.setFoldCompact(Preferences.getEditor("AllFoldCompact"))
    
    def autoCompletionWordSeparators(self):
        """
        Public method to return the list of separators for autocompletion.
        
        @return list of separators (QStringList)
        """
        return QStringList() << ':' << '.'
    
    def isCommentStyle(self, style):
        """
        Public method to check, if a style is a comment style.
        
        @return flag indicating a comment style (boolean)
        """
        return style in [QsciLexerLua.Comment, 
                         QsciLexerLua.LineComment]
    
    def isStringStyle(self, style):
        """
        Public method to check, if a style is a string style.
        
        @return flag indicating a string style (boolean)
        """
        return style in [QsciLexerLua.String, 
                         QsciLexerLua.LiteralString, 
                         QsciLexerLua.UnclosedString]
    
    def defaultKeywords(self, kwSet):
        """
        Public method to get the default keywords.
        
        @param kwSet number of the keyword set (integer)
        @return string giving the keywords (string) or None
        """
        return QsciLexerLua.keywords(self, kwSet)
